@@ -1,19 +1,19 @@
 package AFS::ACL;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)ACL.pm,v 1.2 2002/06/18 05:56:05 nog Exp"
+# RCS-Id: "@(#)$Id: ACL.pm 528 2004-01-06 18:36:03Z nog $"
 #
-# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2004 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #------------------------------------------------------------------------------
 
-use AFS;
+use AFS ();
 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = sprintf("%d.%02d", q/1.2/ =~ /(\d+)\.(\d+)/);
+$VERSION = do{my@r=q/Major Version 2.2 $Rev: 528 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 sub new {
     my ($this, $class);
@@ -62,21 +62,18 @@ sub retrieve {
     my $follow = shift;
 
     $follow = 1 unless defined $follow;
-    AFS::getacl($path, $follow);
+    AFS::_getacl($path, $follow);
 }
 
-{ # this is to please version 1 and to avoid warning about redefined subroutines
-no warnings;
-
 sub modifyacl {
     my $self   = shift;
     my $path   = shift;
     my $follow = shift;
 
-    my($newacl);
+    my $newacl;
 
     $follow = 1 unless defined $follow;
-    if ($newacl = AFS::getacl($path, $follow)) {
+    if ($newacl = AFS::_getacl($path, $follow)) {
         $newacl->add($self);
         AFS::setacl($path, $newacl, $follow);
     }
@@ -89,10 +86,10 @@ sub copyacl {
     my $to     = shift;
     my $follow = shift;
 
-    my($acl);
+    my $acl;
 
     $follow = 1 unless defined $follow;
-    if ($acl = AFS::getacl($from, $follow)) { AFS::setacl($to, $acl, $follow); }
+    if ($acl = AFS::_getacl($from, $follow)) { AFS::setacl($to, $acl, $follow); }
     else { return 0; }
 }
 
@@ -101,10 +98,10 @@ sub cleanacl {
     my $path   = shift;
     my $follow = shift;
 
-    my($acl);
+    my $acl;
 
     $follow = 1 unless defined $follow;
-    if ($acl = AFS::getacl($path, $follow)) { AFS::setacl($path, $acl, $follow); }
+    if ($acl = AFS::_getacl($path, $follow)) { AFS::setacl($path, $acl, $follow); }
     else { return 0; }
 }
 
@@ -126,15 +123,13 @@ sub rights2ascii {
     AFS::rights2ascii(@_);
 }
 
-} # this is to please version 1 and to avoid warning about redefined subroutines
-
 # old form  DEPRECATED !!!!
 sub addacl {
-    my ($self, $macl) = @_;
-    my ($key);
+    my $self = shift;
+    my $macl = shift;
 
-    foreach $key ($macl->keys)  { $self->set($key, $macl->get($key)); }
-    foreach $key ($macl->nkeys) { $self->nset($key, $macl->nget($key)); }
+    foreach my $key ($macl->keys)  { $self->set($key, $macl->get($key)); }
+    foreach my $key ($macl->nkeys) { $self->nset($key, $macl->nget($key)); }
     return $self;
 }
 
