@@ -1,8 +1,8 @@
 package AFS::FS;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)FS.pm,v 2.0 2002/07/02 06:12:27 nog Exp"
+# RCS-Id: "@(#)$Id: FS.pm 528 2004-01-06 18:36:03Z nog $"
 #
-# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2004 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
@@ -15,7 +15,6 @@ use vars qw(@ISA $VERSION @EXPORT_OK);
 require Exporter;
 
 @EXPORT_OK = qw(
-                getfid
                 getquota
                 isafs
                 lsmount
@@ -24,7 +23,7 @@ require Exporter;
                 setquota
                 whereis
                );
-@ISA       = qw(Exporter AFS);
-$VERSION   = sprintf("%d.%02d", q/2.0/ =~ /(\d+)\.(\d+)/);
+@ISA     = qw(Exporter AFS);
+$VERSION = do{my@r=q/Major Version 2.2 $Rev: 528 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 1;
