@@ -1,22 +1,19 @@
 package AFS::PTS;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)PTS.pm,v 2.0 2002/07/02 06:13:51 nog Exp"
+# RCS-Id: "@(#)$Id: PTS.pm 528 2004-01-06 18:36:03Z nog $"
 #
-# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2004 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #------------------------------------------------------------------------------
 
-use AFS;
+use AFS ();
 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = sprintf("%d.%02d", q/2.0/ =~ /(\d+)\.(\d+)/);
-
-{ # this is to please version 1 and to avoid warning about redefined subroutines
-no warnings;
+$VERSION = do{my@r=q/Major Version 2.2 $Rev: 528 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 sub new {
     # this whole construct is to please the old version from Roland
@@ -30,6 +27,12 @@ sub new {
     AFS::PTS::_new('AFS::PTS', @args);
 }
 
+sub DESTROY {
+    my (undef, undef, undef, $subroutine) = caller(1);
+    if (! $subroutine) { undef $_[0]; }    # self->DESTROY
+    else { AFS::PTS::_DESTROY($_[0]); }    # undef self
+}
+
 sub ascii2ptsaccess {
     my $class  = shift;
 
@@ -48,6 +51,4 @@ sub convert_numeric_names {
     AFS::convert_numeric_names(@_);
 }
 
-}
-
 1;
